#
# spec file for package virt-v2v
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#
# needsbinariesforbuild


# If there are patches which touch autotools files, set this to 1.
%global patches_touch_autotools 1
# The source directory.
#%global source_directory 2.6-stable
%global source_directory 2.7-development
Name:           virt-v2v
Version:        2.7.8
Release:        1.1
Summary:        Tools to convert a virtual machine to run on KVM
License:        GPL-2.0-or-later
Group:          System/Management
URL:            https://github.com/libguestfs/virt-v2v
Source0:        https://download.libguestfs.org/virt-v2v/%{source_directory}/%{name}-%{version}.tar.gz
Source1:        https://download.libguestfs.org/virt-v2v/%{source_directory}/%{name}-%{version}.tar.gz.sig

BuildRequires:  augeas-devel
BuildRequires:  file-devel
#BuildRequires: /usr/bin/pod2man
BuildRequires:  gcc
BuildRequires:  gettext-devel
BuildRequires:  glib2-devel
BuildRequires:  libguestfs-devel >= 1.55.6
BuildRequires:  libjson-c-devel
BuildRequires:  libnbd
BuildRequires:  libosinfo-devel
BuildRequires:  libvirt-devel
BuildRequires:  libxml2-devel
BuildRequires:  mkisofs
BuildRequires:  ocaml-fileutils-devel
BuildRequires:  ocaml-findlib-devel
BuildRequires:  ocaml-gettext-devel
BuildRequires:  ocaml-hivex-devel
BuildRequires:  ocaml-libguestfs
BuildRequires:  ocaml-libguestfs-devel
BuildRequires:  ocaml-libvirt-devel
BuildRequires:  ocaml-ounit-devel
BuildRequires:  pcre2-devel
BuildRequires:  pkgconfig
BuildRequires:  po4a
BuildRequires:  qemu-tools
BuildRequires:  ocaml(ocaml_base_version) >= 4.07
BuildRequires:  perl(Sys::Guestfs)
BuildRequires:  pkgconfig(bash-completion) >= 2.0
BuildRequires:  pkgconfig(libnbd)
Requires:       %{_bindir}/gawk
Requires:       %{_bindir}/gzip
Requires:       %{_bindir}/qemu-nbd
Requires:       %{_bindir}/virsh
Requires:       guestfs-tools >= 1.53.8
Requires:       libguestfs >= 1.55.6
Requires:       libguestfs-winsupport
Requires:       libguestfs0 >= 1.55.6
Requires:       libnbd
Requires:       nbdkit
Requires:       nbdkit-curl-plugin
Requires:       nbdkit-nbd-plugin
Requires:       nbdkit-python-plugin
Requires:       nbdkit-ssh-plugin
%ifarch x86_64
Requires:       nbdkit-vddk-plugin
%endif
Requires:       openssh-clients
Requires:       ovmf
Requires:       unzip
# Build only for architectures that have a kernel
ExclusiveArch:  x86_64 ppc64le s390x aarch64 riscv64
%if 0%{patches_touch_autotools}
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  libtool
%endif

%description
Virt-v2v converts a single guest from a foreign hypervisor to run on
KVM.  It can read Linux and Windows guests running on VMware, Xen,
Hyper-V and some other hypervisors, and convert them to KVM managed by
libvirt, OpenStack, oVirt, Red Hat Virtualisation (RHV) or several
other targets.  It can modify the guest to make it bootable on KVM and
install virtio drivers so it will run quickly.

%package bash-completion
Summary:        Bash tab-completion for %{name}
Group:          System/Management
Requires:       %{name} = %{version}-%{release}
Requires:       bash-completion >= 2.0
Supplements:    (%{name} and bash-completion)
BuildArch:      noarch

%description bash-completion
Install this package if you want intelligent bash tab-completion
for %{name}.

%package man-pages-ja
Summary:        Japanese (ja) man pages for %{name}
Group:          System/Management
Requires:       %{name} = %{version}-%{release}
BuildArch:      noarch

%description man-pages-ja
%{name}-man-pages-ja contains Japanese (ja) man pages
for %{name}.

%package man-pages-uk
Summary:        Ukrainian (uk) man pages for %{name}
Group:          System/Management
Requires:       %{name} = %{version}-%{release}
BuildArch:      noarch

%description man-pages-uk
%{name}-man-pages-uk contains Ukrainian (uk) man pages
for %{name}.

%prep
%autosetup -p1

%build
%if 0%{patches_touch_autotools}
autoreconf -fi
%endif
%configure
%make_build

%install
%make_install

# Delete libtool crap.
find %{buildroot} -type f -name "*.la" -delete -print

# Virt-tools data directory.  This contains a symlink to rhsrvany.exe
# which is satisfied by the dependency on mingw32-srvany.
mkdir -p %{buildroot}/%{_datadir}/virt-tools

# Delete the v2v test harness (except for the man page).
#rm -r %{buildroot}/%{_libdir}/ocaml/v2v_test_harness
#rm -r %{buildroot}/%{_libdir}/ocaml/stublibs/dllv2v_test_harness*

# Find locale files.
%find_lang %{name}

%check
# All tests fail at the moment because of bugs in libvirt blockdev.
# # Tests fail on both armv7 and ppc64le in Fedora 31 because the kernel
# # cannot boot on qemu.
# %ifnarch %{arm} ppc64le

# # On x86_64 this single test fails with: "virt-v2v: warning: the
# # target hypervisor does not support a x86_64 KVM guest".  Missing
# # BuildRequires?
# %ifarch x86_64
# truncate -s 0 tests/test-v2v-o-libvirt.sh
# %endif

# # This test fails in mock.
# truncate -s 0 tests/test-v2v-oa-option.sh

# # Make sure we can see the debug messages (RHBZ#1230160).
# export LIBGUESTFS_DEBUG=1
# export LIBGUESTFS_TRACE=1

# make %{?_smp_mflags} check || {
#     cat tests/test-suite.log
#     exit 1
#   }

# %endif

%files -f %{name}.lang
%license COPYING
#doc README
%{_bindir}/virt-v2v
%{_bindir}/virt-v2v-in-place
%{_bindir}/virt-v2v-inspector
%{_mandir}/man1/virt-v2v.1%{?ext_man}
%{_mandir}/man1/virt-v2v-in-place.1%{?ext_man}
%{_mandir}/man1/virt-v2v-hacking.1%{?ext_man}
%{_mandir}/man1/virt-v2v-input-vmware.1%{?ext_man}
%{_mandir}/man1/virt-v2v-input-xen.1%{?ext_man}
%{_mandir}/man1/virt-v2v-output-local.1%{?ext_man}
%{_mandir}/man1/virt-v2v-output-openstack.1%{?ext_man}
%{_mandir}/man1/virt-v2v-output-rhv.1%{?ext_man}
%{_mandir}/man1/virt-v2v-release-notes-1.42.1%{?ext_man}
%{_mandir}/man1/virt-v2v-release-notes-2.0.1%{?ext_man}
%{_mandir}/man1/virt-v2v-release-notes-2.4.1%{?ext_man}
%{_mandir}/man1/virt-v2v-release-notes-2.6.1%{?ext_man}
%{_mandir}/man1/virt-v2v-support.1%{?ext_man}
%{_mandir}/man1/virt-v2v-inspector.1.gz
%{_mandir}/man1/virt-v2v-release-notes-2.2.1.gz
%{_datadir}/virt-tools

%files bash-completion
%license COPYING
%{_datadir}/bash-completion/completions/virt-v2v

%files man-pages-ja
%license COPYING
%lang(ja) %{_mandir}/ja/man1/*.1*
%dir %{_mandir}/ja
%dir %{_mandir}/ja/man1/

%files man-pages-uk
%license COPYING
%lang(uk) %{_mandir}/uk/man1/*.1*
%dir %{_mandir}/uk
%dir %{_mandir}/uk/man1/

%changelog
* Wed Mar 12 2025 carnold@suse.com
- Update to virt-v2v 2.7.8 (jsc#PED-8910)
  * convert: Drop kmod-xenpv-* handling
  * Remove more RHEL 3 support
  * convert: Handle large output from 'rpm -ql' command
    This requires the new guestfs_sh_out API from libguestfs 1.55.6.
  * mlstdutils: Reimplement String.find, add String.find_from
  * mlstdutils: Reimplement String.nsplit tail recursively
  * mldrivers: Handle large output from 'rpm -ql' command
  * mlcustomize: Drop old virtio-win dir name scraping
* Mon Mar  3 2025 carnold@suse.com
- Update to virt-v2v 2.7.7 (jsc#PED-8910)
  * convert: Drop kmod-xenpv-* handling
  * Remove more RHEL 3 support
  * convert: Handle large output from 'rpm -ql' command
  * mlcustomize: Drop old virtio-win dir name scraping
* Tue Feb 18 2025 carnold@suse.com
- Update to virt-v2v 2.7.6 (jsc#PED-8910)
  * mldrivers/linux_bootloaders.ml: Don't overwrite EFI grub2 wrapper
  * convert: Use yum/apt/... for package removals, not rpm/dpkg
  * convert: Reload augeas after package remove
* Wed Feb 12 2025 carnold@suse.com
- Update to virt-v2v 2.7.5 (jsc#PED-8910)
  * Various language translation updates
  * po-docs: fixes and adjustments
  * valgrind: Add suppressions for two new memory leaks in glib
* Fri Jan  3 2025 carnold@suse.com
- Update to virt-v2v 2.7.4 (jsc#PED-8910)
  * mltools: Replace jansson with json-c
  * lib: OVF: Add preliminary support for Windows Server 2025
  * in-place: Add a warning about checking the exit code
  * -i libvirtxml: Implement disk checksumming
  * v2v: Allow printing the checksum
  * -i libvirt: Trim whitespace around name
  * -o qemu: Replace hard-coded UEFI paths
  * -o qemu: Add set -e, -x at the top of the output script
  * -o qemu: Remove confusing comment about smm
  * lib, input: Model UEFI secureboot property in metadata
  * -i vmx: Parse uefi.secureBoot.enabled from vmx file
  * -o libvirt: Add full <firmware/> section
  * -o libvirt: Remove incorrect comment about secure boot
  * -i libvirt: Parse UEFI secureboot flag from libvirt XML
  * build: Move baseline OCaml to 4.08
  * build: Depend on libnbd >= 1.14
  * build: Use nbdcopy and nbdinfo from ./configure
  * v2v: Implement --parallel=N for parallel disk copies
  * in-place: Fix name of program in the --help output
  * inspector: Reorder -O option in alphabetical order
  * v2v: Ensure --parallel >= 1
  * inspector: Move the code that creates XML output to a separate file
  * in-place: Add new -O option to write inspector XML
* Thu Oct 10 2024 carnold@suse.com
- Update to virt-v2v 2.6.0 (jsc#PED-8910)
  * You can now use most virt-customize(1) options, such as
    installing arbitrary firstboot scripts, uploading or editing
    files, etc. during conversions.
  * Installation of QEMU Guest Agent in Windows guests has been
    revised and made much more reliable. Note that a visible effect
    of this change is that Windows guests may reboot four or more
    times during the first boot after conversion (which is
    necessary). (Thanks Vadim Rozenfeld, Konstantin Kostiuk, Yuri
    Benditovich, Yan Vugenfirer).
  * We now forcibly online all virtio disks during firstboot,
    working around a security mitigation in recent versions of
    Windows that offlines them if they change bus (Martin Necas).
  * QEMU Balloon Server (blnsvr) is now installed in Windows
    guests, if found on the virtio-win ISO. This improves
    statistics gathering for these guests.
  * Add support for Circle Linux (Bella Zhang).
  * Add some support for LoongArch guests (liuxiang).
  * -i ova mode now uses the detected guest firmware, if it's not
    specified in the OVA metadata (Bella Khizgiyaev).
  * -o kubevirt output mode has been substantially changed to fix
    multiple problems. It should be more compatible with real
    KubeVirt instances now. (Thanks Arik Hadas, Bella Khizgiyaev,
    Lee Yarwood, Martin Necas).
  * -o libvirt mode now includes an <os firmware> attribute
    specifying whether the guest needs BIOS or UEFI to boot.
  * The output of virt-v2v-inspector(1) has been revised, with much
    more metadata available.
  * The --mac option now allows the gateway and network mask length
    to be empty (Arik Hadas).
  * The debug output of virt-v2v has been improved. Now when
    searching the log for important events, you can just use the
    regular expression /^info:/
  * Added a test for -o kubevirt mode.
- Bug fixes
  * document that vmx+ssh "-ip" auth doesn't cover ssh / scp shell
    commands
  * Exact string (including the literal *) should be used when
    converting guest via vmx by v2v
  * Missing firmware type for kubvirt and local output
  * Virt-v2v can't convert guest from maintained ESXi hosts with
    vddk > 6
  * Migrated Windows VMs require the BLNSVR.exe service to be
    installed for accurate memory reporting
  * Re-add the info about non-interactive authentication back into
    virt-v2v-input-xen
  * Missing OS info for kubevirt output
  * qemu-guest-agent not being installed at first boot in Windows
    Server 2022
  * Allow --mac gw and len fields to be optional
  * Uninstalling vmware-tools from windows guest sometimes fails
    with exit code 1618 or exit code 1603
  * network configuration script does not work for Windows 10 i386
    guest
  * Re-enable Windows disks post-live migration [rhel-9.5]
  * Re-enable Windows disks post-live migration [rhel-9.4.z]
  * window version shows incorrect during converting win11 guest
    with build number 22631 by virt-v2v
  * v2v: The -o kubevirt firmware is not compatible with kubevirt
    api
  * rhv-upload broken since Ovirt 4.5, cause Basic Auth has been
    removed
  * virt-v2v missing firmware type for kubvirt and local output
  * Clustername not working when on same Data Center, sharing same
    storage domains
* Fri Sep 20 2024 carnold@suse.com
- Update to virt-v2v 2.5.10 (jsc#PED-8910)
  * convert: Display osinfo in "Converting ..." message
  * Updated language translations
  * Fix the bugs in YAML generator
  * output: -o kubevirt: Fix firmware section to match specification
* Thu Aug 29 2024 carnold@suse.com
- Update to virt-v2v 2.5.9 (jsc#PED-8910)
  * convert: More robust qemu-ga installation, change paths
    mlcustomize: Use Start-Process -Wait to run qemu-ga installer
    mlcustomize: Add Firstboot.firstboot_dir function
    mlcustomize: Place powershell scripts into <firstboot_dir>\Temp
  * common: mlcustomize: Inject qemu-ga & blnsvr into
    <firstboot_dir>/Temp
  * Pull in a fix to make Windows firstboot more reliable.
    mlcustomize: Add some comments to firstboot batch file
    mlcustomize: Reboot Windows between each firstboot script
  * convert: windows: Don't wait indefinitely for netkvm.sys
  * convert: windows: Allow increasing verboseness of driver
    installation
  * convert: windows: Online all virtio disks at first boot
  * convert: windows: Ignore sriov drivers on virtio-win disk
* Tue Aug  6 2024 carnold@suse.com
- Update to virt-v2v 2.5.6 (jsc#PED-8910)
  * -i ova: Ignore dot-underscore-files in OVA files
  * mlcustomize: firstboot: Use Linux path for Powershell script path
  * mlcustomize: firstboot: Use powershell.exe instead of path
  * mlcustomize: firstboot: Use Powershell -NoProfile flag
  * mlcustomize: Revert delay installation of qemu-ga MSI
  * --mac: Allow gw and len fields to be empty
  * Debugging enhancements
* Mon Jul 15 2024 carnold@suse.com
- Update to virt-v2v 2.5.5 (jsc#PED-6305)
  * -i vmx: Remove scp -T option
  * -i vmx: Refactor ssh/scp code into a new module
  * -i vmx: Simplify scp wrapper
  * -i vmx: Add the input password to vmx_source
  * -i vmx: Remove dependency of ssh.ml on Xml.uri
  * -i vmx: Replace external ssh/scp with nbdkit-ssh-plugin
  * input/nbdkit_ssh: Make retry filter optional
  * input/nbdkit_ssh: Make password parameter optional
  * input/ssh: Use nbdinfo --can connect (instead of --size)
  * add CircleLinux to supported distros
  * Add support for LoongArch
  * -o rhv-upload: fix rhv-upload function to work with keycloak
    instead of basic auth only (#43)
  * -o rhv-upload: Add context if parsing params fails (#47)
  * -o rhv-upload: clarify debug message
  * -o rhv-upload: Dump the JSON before parsing
  * -o rhv-upload: Output outside of the with block
  * -o rhv-upload: Improve host id logging
  * -o rhv-upload: Don't share transfer.json (#49)
  * -o rhv-upload: Add O_TRUNC to truncate JSON file if it exists
  * -o kubevirt: Add os firmware field in output
  * -o kubevirt: Add CPU model & topology when available
  * -o kubevirt: Add network interfaces to output
  * -o kubevirt: Add an RNG device if virtio-rng driver in the
    guest
  * -o kubevirt: Use virtio-transitional for ancient guests
  * -o kubevirt: Add support for sound device
  * -o kubevirt: Add metadata labels
  * -o kubevirt: Create a VirtualMachine instead of a
    VirtualMachineInstance
  * -o libvirt: Use <os firmware='efi'> finally
  * -i ova: Use the detected firmware type when absent rather than
    default (#53)
  * Fix bytecode compilation to output whole exe instead of using
  - custom
  * convert: windows: Install blnsvr from virtio-win
* Tue May  7 2024 carnold@suse.com
- bsc#1223444 - New virt-v2v dependency on btrfsprogs causes error
  with zypper dup on systems without btrfs installed
  Drop Requires on the following packages and move them into
  libguestfs-appliance
  btrfsprogs, curl, dhcp-client, e2fsprogs, gptfdisk
  ntfsprogs, xfsprogs
* Fri Apr 19 2024 carnold@suse.com
- Add Requires for dhcp-client
- Add conditional x86_64 arch Requires for nbdkit-vddk-plugin
* Thu Apr 18 2024 carnold@suse.com
- bsc#1223093 - virt-v2v needs nbdkit and libnbd on SLE15-SP6 to
  function correctly
  Add Requires on libnbd and all nbdkit packages. The nbdkit
  packages are required for remote execution.
  Added Requires on btrfsprogs
* Fri Mar 29 2024 carnold@suse.com
- Add Requires on gptfdisk and libguestfs-winsupport for
  converting windows VMs.
* Fri Jan 19 2024 olaf@aepfle.de
- Relax the openssh requirement. Options passed to scp are known
  by openssh 8.4
- Move autoreconf from prep to build, to simplify quilt setup.
* Thu Jan  4 2024 carnold@suse.com
- Update to virt-v2v 2.4.0 (jsc#PED-6305)
  * New --block-driver option which can be used to choose to
    install either virtio-blk or virtio-scsi drivers
  * The virt-v2v --key option now recognizes LVM names like
    /dev/mapper/rhel_bootp--73--75--123-root
  * The --key option also supports a new --key all:... selector to
    try the same key on all devices.
  * Conversions now set the host-model CPU in the output metadata,
    except where the source hypervisor overrides this. The
    exception is -o qemu mode which uses -cpu host.
  * virt-v2v will now look for bootloader configuration in
    /boot/grub/grub.cfg for UEFI guests
  * Invoke pnputil (if available) to install drivers, fixing some
    Windows conversions
  * Skip SELinux relabelling if the guest has disabled SELinux
  * Several output modes now generate metadata to indicate whether
    the guest requires the RTC to be set to UTC (Linux) or
    localtime (most Windows). For example with -o libvirt this
    generates <clock offset="utc|localtime"/>.
  * -i ova mode is now less strict about parsing the manifest file,
    which helps when converting some non-conforming OVA files.
  * Input modes using -it ssh now use the correct quoting
  * -i vmx mode now rejects VMDK files explicitly, reducing a
    source of user confusion
  * Multiple fixes to -o kubevirt mode. Also implement -oo
    compressed for this mode.
  * -o libvirt mode now supports Rocky Linux
  * -o openstack documentation for cloud configurations fixed
  * -o rhv-upload mode has an improved error when the -os parameter
    is invalid or missing
  * Remove support for RHEL 3
  * Various language translation updates
- Drop patches
  fix-compiler-error-Stdlib.stderr.patch
  fix-linker-error.patch
* Thu Nov 30 2023 olaf@aepfle.de
- Remove obsolete requirement for ocaml-gettext-stub-devel
- Require OCaml 4.07+
- Align ExclusiveArch with libguestfs
* Wed Feb  8 2023 carnold@suse.com
- Update to virt-v2v 2.2.0
  * New virt-v2v-inspector(1) tool. This tool can be used before
    conversion to collect facts about the source guest, such as
    number of disks, and to estimate the disk space required after
    conversion.
  * Add support for NVMe devices and SATA hard disks when importing
    from VMware VMX files (Laszlo Ersek).
  * Add support for importing to KubeVirt using the new
    experimental -o kubevirt mode.
  * Windows 11 guests are now supported.
  * Rocky Linux guest support has been added (Andrey Drobyshev).
  * The -o json mode was removed. It was intended to be used with
    KubeVirt but was never actually used there. Use -o kubevirt
    instead.
  * Numerous bug fixes and build changes
* Tue Oct  4 2022 carnold@suse.com
- jsc#PED-2113 [Virt Tools] Refresh Virtualization Tools for Xen
  and KVM Management
* Tue Jul 12 2022 carnold@suse.com
- Update to version 2.0.7
  * This is a bug fix release
  fix-compiler-error-Stdlib.stderr.patch
- Drop patch contained in new tarball
  CVE-2022-2211-options-fix-buffer-overflow-in-get_keys.patch
* Wed Jun 29 2022 carnold@suse.com
- bsc#1201064 - Libguestfs: Buffer overflow in get_keys leads
  to DOS - CVE-2022-2211
  CVE-2022-2211-options-fix-buffer-overflow-in-get_keys.patch
* Thu May 26 2022 carnold@suse.com
- Update to version 2.0.6
  * This is a bug fix release on top of 2.0.5
* Thu May 12 2022 carnold@suse.com
- Update to version 2.0.5
  * Virt-v2v has been modularised allowing external programs to
    examine the state of the conversion and inject their own
    copying step. Further enhancements will be made to this new
    architecture in forthcoming releases.
  * The command line is almost identical apart from some debugging
    features that were removed (see below). The only significant
    difference is that the output format (-of) now has to be
    specified if it is different from the input format, whereas
    previous versions of virt-v2v would use the same output format
    as input format automatically.
  * A lot of time was spent improving the performance of virt-v2v
    in common cases.
  * Implement conversion of ALT Linux guests (Mikhail Gordeev).
  * Many bug fixes and performance enhancements were made to oVirt
    imageio output (Nir Soffer).
  * There is a new virt-v2v-in-place(1) tool which replaces the
    existing virt-v2v --in-place option.
  * Virt-v2v can now convert guests which use LUKS encrypted
    logical volumes (Laszlo Ersek).
  * Option -oo rhv-direct has been replaced by -oo rhv-proxy, and
    direct mode (which is much faster) is now the default when
    writing to oVirt, with proxy mode available for restricted
    network configurations (thanks: Nir Soffer).
  * The following command line options were removed:
  - -print-estimate, --debug-overlays, --no-copy.
  * Virt-v2v no longer installs the RHEV-APT tool in Windows
    guests. This tool was deprecated and then removed in oVirt 4.3.
  * Deprecated tool virt-v2v-copy-to-local has been removed.
    This was deprecated in November 2018.
* Thu Jan  6 2022 carnold@suse.com
- Update to version 1.44.2
  * This is a bug fix release
  virt-v2v-1.44.2.tar.gz.sig
- Drop virt-v2v-1.44.0.tar.gz.sig
* Thu Sep 16 2021 carnold@suse.com
- Fix ocaml linker error due to unresolved 'rpl_free'. For
  comparison, see libguestfs commit 489b14b75e.
  fix-linker-error.patch
* Fri May  7 2021 carnold@suse.com
- Update to version 1.44.0
  Include virt-v2v-1.44.0.tar.gz.sig
  * windows: Allow qxldod.inf as synonym for qxl.inf
  * -i ova: Set LANG=C and --no-auto-compress when running tar.
  * Increase required free space in Windows to 100 MB
  * Tidy up error messages when mounting a virtio-win ISO
* Thu Apr 29 2021 Predrag Ivanović <predivan@mts.rs>
- Update to version 1.43.5
  * No upstream provided Changelog
- Package changes
  * Switch BuildRequires pcre-devel to pcre2-devel
  * Ran spec-cleaner
* Wed Feb 10 2021 Jan Engelhardt <jengelh@inai.de>
- Remove old specfile macros and constructs.
* Thu Jan 28 2021 carnold@suse.com
- Update to version 1.43.3
  * Support for ALT Linux 9 and up added
  * Many upstream bug fixes
  * Language file fixes and updates
* Thu Dec  3 2020 Predrag Ivanović <predivan@mts.rs>
- Update to version 1.43.2
  * No upstream provided Changelog.
* Thu Oct  1 2020 Predrag Ivanović <predivan@mts.rs>
-  Fix rpmbuild 'directories not owned by package' error on Leap
-  Fix Requires referencing  wrong/non-existing packages
* Mon Jul 20 2020 carnold@suse.com
- Update to version 1.43.1
  * Several bug fixes
- Drop fix-redefinition-error.patch
* Tue May  5 2020 carnold@suse.com
- Fix error: redefinition of 'glib_autoptr_clear_OsinfoList'
  fix-redefinition-error.patch
* Wed Apr 22 2020 carnold@suse.com
- Initial package of virt-v2v version 1.42.0
  * The rhv-upload output mode of virt-v2v is not listed as output
    driver, as virt-p2v does not provide all the GUI elements to
    properly use it
  * Virt-v2v is checked as requirement for the functional tests,
    in addition to guestfish, and virt-customize
  * Virt-p2v-make-disk now sets p2v.local as hostname in the
    generated disk image
  * Document p2v as initial password for the root user on the disk
    image generated by virt-p2v-make-disk, virt-p2v-make-kickstart,
    and virt-p2v-make-kiwi
